# !/usr/bin/python
# -*- coding: utf-8 -*-
# @Author:: Arthur Wu
# @Description:: 游客登录，加购促销白名单商品并结算
# @Date:: 2021-05-10 16:30:23
import unittest,allure,time,pytest,ddt
from YiMao.businessFunc.ClientApiLib import YMClientApi
from YiMao.businessFunc.ServiceApiLib import YMServiceApi
from configs.globalParams import DataInit
DescName = "Anon006-非会员加购促销白名单商品并结算"

@ddt.ddt
class Test_CAnon006(unittest.TestCase):
    f'''@Date:: 2024/11/15
    @Author:: Arthur Wu
    @Desc:: 
    [购物车客户端] {DescName}
    '''
    @ddt.data(*DataInit)
    def test_CAnon006_AddPromotionalWhitelistProducts(self, data):
        allure.dynamic.story(f'[{data['MarketName']}-场景测试] {DescName}验证')
        allure.dynamic.description(f"描述：{data['MarketName']}-{DescName}\n")
        ymc = YMClientApi(data["ShoppingCartMac"])
        yms = YMServiceApi()
        promotional_whitelist_goods = data["PromotionalWhitelistGoods"]
        market_and_store_info = {
            "MarketId": data["MarketAndStoreDetails"]['putMarketId'],
            "StoreId": data["MarketAndStoreDetails"]['putStoreId'][0]
        }

        allure.step("[前置条件]：先调用管理平台接口，将指定商品添加到促销白名单中")
        pre_respomse = yms.add_promotional_product_whitelist(
            promotional_whitelist_goods, market_and_store_info
        )
        if pre_respomse['data'] is not None:
            allure.step("[业务步骤]：再调用客户端接口，执行加购操作")
            allure.step("步骤1：session开始")
            ymc.session_start()
            allure.step("步骤2：匿名登录")
            Payload01 = {"action": 0, "isAnon": True}
            LoginData = ymc.login_app_v2(Payload01)
            allure.step("步骤3：获取白名单商品信息")
            GoodsInfoData1 = ymc.get_goods_info(promotional_whitelist_goods["GoodsInputcode"])
            if GoodsInfoData1['msg'] != '加购商品不存在':
                allure.step("步骤4：加购白名单商品")
                ymc.add_cart_goods(GoodsInfoData1, 1, LoginData)
                allure.step("步骤5：获取购物车商品信息")
                ymc.get_cart_goods_info([GoodsInfoData1])
                allure.step("步骤6：请求订单结算")
                ymc.request_order_settlement(LoginData)
                allure.step("[后置处理]：删除添加的促销白名单商品")
                yms.delete_whitelist_goods()
            else:
                allure.step("[后置处理]：删除添加的促销白名单商品")
                yms.delete_whitelist_goods()
                pytest.fail(f"商品 {promotional_whitelist_goods["GoodsInputcode"]}不存在")
        else:
            pytest.fail(f"---添加商品 {promotional_whitelist_goods['GoodsInputcode']} "
                        f"到促销白名单失败")


if __name__ == '__main__':
    unittest.main(verbosity=2)