# !/usr/bin/python
# -*- coding: utf-8 -*-
# @Author:: Arthur Wu
# @Description:: 游客转会员登录，加购重量放通商品，并结算
# @Date:: 2024/11/21
import unittest,allure,time,pytest,ddt
from configs.globalObj import LOGGER
from YiMao.businessFunc.ClientApiLib import YMClientApi
from YiMao.businessFunc.ServiceApiLib import YMServiceApi
from configs.globalParams import DataInit
DescName = "Vip007-游客转会员登录，加购重量放通商品，并结算"

@ddt.ddt
class Test_CVip007(unittest.TestCase):
    f'''@Date:: 2024/11/15
    @Author:: Arthur Wu
    @Desc::
    [购物车客户端] {DescName}
    '''

    @ddt.data(*DataInit)
    def test_CVip007_AddWeightToTheProduct(self,data):
        allure.dynamic.story(f'[{data['MarketName']}-场景测试] {DescName}验证')
        allure.dynamic.description(f"描述：{data['MarketName']}-{DescName}\n")
        ymc = YMClientApi(data["ShoppingCartMac"])
        yms = YMServiceApi()
        vip_phone_num = data["VIPPhoneNumber"]
        weight_to_whitelist_goods = data["WeightToWhitelistGoods"]
        market_and_store_info = {
            "MarketId": data["MarketAndStoreDetails"]["putMarketId"],
            "StoreId": data["MarketAndStoreDetails"]["putStoreId"][0]
        }

        allure.step("[前置条件]：先调用管理平台接口，将指定商品添加到重量放通白名单中")
        pre_respomse = yms.add_weight_to_whitelist(
            weight_to_whitelist_goods, market_and_store_info
        )
        if pre_respomse['data'] is not None:
            LOGGER.info(f"---商品 {weight_to_whitelist_goods['GoodsInputcode']} "
                        f"已添加到重量放通白名单中")
            ''' 2-再调用客户端接口，执行加购操作 '''
            allure.step("[业务步骤]：再调用客户端接口，执行加购操作")
            allure.step("步骤1：session开始")
            ymc.session_start()
            allure.step("步骤2：匿名登录")
            Payload01 = {"action": 0, "isAnon": True}
            LoginData = ymc.login_app_v2(Payload01)

            allure.step("步骤3：切换会员登录")
            Payload02 = {"action": 1, "code": vip_phone_num, "isAnon": False}
            ymc.login_app_v2(Payload02)

            allure.step("步骤3：获取白名单商品信息")
            GoodsInfoData1 = ymc.get_goods_info(weight_to_whitelist_goods["GoodsInputcode"])
            if GoodsInfoData1['msg'] != '加购商品不存在':
                allure.step("步骤4：加购白名单商品")
                ymc.add_cart_goods(GoodsInfoData1, 1, LoginData)
                allure.step("步骤5：获取购物车商品信息")
                ymc.get_cart_goods_info([GoodsInfoData1])
                allure.step("步骤6：请求订单结算")
                ymc.request_order_settlement(LoginData)
                allure.step("[后置处理]：删除添加的重量放通白名单商品")
                yms.delete_weight_whitelist_goods()
            else:
                allure.step("[后置处理]：删除添加的重量放通白名单商品")
                yms.delete_weight_whitelist_goods()
                pytest.fail(f"---商品 {weight_to_whitelist_goods["GoodsInputcode"]} 不存在")
        else:
            pytest.fail(f"---添加商品 {weight_to_whitelist_goods['GoodsInputcode']} "
                            f"到重量放通白名单失败")


if __name__ == '__main__':
    unittest.main(verbosity=2)